[Python-checkins] cpython (merge 3.2 -> 3.3): #11379: merge with 3.2.

ezio.melotti python-checkins at python.org
Tue Jan 22 21:50:25 CET 2013


http://hg.python.org/cpython/rev/8ff512910338
changeset:   81666:8ff512910338
branch:      3.3
parent:      81662:f4e00073e80c
parent:      81665:b9c0e050c935
user:        Ezio Melotti <ezio.melotti at gmail.com>
date:        Tue Jan 22 22:49:46 2013 +0200
summary:
  #11379: merge with 3.2.

files:
  Doc/library/xml.dom.minidom.rst |  22 +++++++-------------
  Lib/xml/dom/minidom.py          |   5 ++-
  2 files changed, 11 insertions(+), 16 deletions(-)


diff --git a/Doc/library/xml.dom.minidom.rst b/Doc/library/xml.dom.minidom.rst
--- a/Doc/library/xml.dom.minidom.rst
+++ b/Doc/library/xml.dom.minidom.rst
@@ -1,8 +1,8 @@
-:mod:`xml.dom.minidom` --- Lightweight DOM implementation
-=========================================================
+:mod:`xml.dom.minidom` --- Minimal DOM implementation
+=====================================================
 
 .. module:: xml.dom.minidom
-   :synopsis: Lightweight Document Object Model (DOM) implementation.
+   :synopsis: Minimal Document Object Model (DOM) implementation.
 .. moduleauthor:: Paul Prescod <paul at prescod.net>
 .. sectionauthor:: Paul Prescod <paul at prescod.net>
 .. sectionauthor:: Martin v. Löwis <martin at v.loewis.de>
@@ -11,17 +11,11 @@
 
 --------------
 
-:mod:`xml.dom.minidom` is a light-weight implementation of the Document Object
-Model interface.  It is intended to be simpler than the full DOM and also
-significantly smaller.
-
-.. note::
-
-   The :mod:`xml.dom.minidom` module provides an implementation of the W3C-DOM,
-   with an API similar to that in other programming languages.  Users who are
-   unfamiliar with the W3C-DOM interface or who would like to write less code
-   for processing XML files should consider using the
-   :mod:`xml.etree.ElementTree` module instead.
+:mod:`xml.dom.minidom` is a minimal implementation of the Document Object
+Model interface, with an API similar to that in other languages.  It is intended
+to be simpler than the full DOM and also significantly smaller.  Users who are
+not already proficient with the DOM should consider using the
+:mod:`xml.etree.ElementTree` module for their XML processing instead
 
 DOM applications typically start by parsing some XML into a DOM.  With
 :mod:`xml.dom.minidom`, this is done through the parse functions::
diff --git a/Lib/xml/dom/minidom.py b/Lib/xml/dom/minidom.py
--- a/Lib/xml/dom/minidom.py
+++ b/Lib/xml/dom/minidom.py
@@ -1,5 +1,6 @@
-"""\
-minidom.py -- a lightweight DOM implementation.
+"""Simple implementation of the Level 1 DOM.
+
+Namespaces and other minor Level 2 features are also supported.
 
 parse("foo.xml")
 

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list